# Generated by Django 2.1.7 on 2020-07-20 14:46

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('log', '0007_auto_20200716_1451'),
    ]

    operations = [
        migrations.AlterField(
            model_name='clienteerro',
            name='origem_delete_tipo',
            field=models.CharField(default='USR.PROFILE', max_length=200, null=True),
        ),
        migrations.AlterField(
            model_name='clienteerro',
            name='origem_edicao_tipo',
            field=models.CharField(default='USR.PROFILE', max_length=200, null=True),
        ),
        migrations.AlterField(
            model_name='clienteerro',
            name='origem_insercao_tipo',
            field=models.CharField(default='USR.PROFILE', max_length=200, null=True),
        ),
        migrations.AlterField(
            model_name='clientelog',
            name='origem_delete_tipo',
            field=models.CharField(default='USR.PROFILE', max_length=200, null=True),
        ),
        migrations.AlterField(
            model_name='clientelog',
            name='origem_edicao_tipo',
            field=models.CharField(default='USR.PROFILE', max_length=200, null=True),
        ),
        migrations.AlterField(
            model_name='clientelog',
            name='origem_insercao_tipo',
            field=models.CharField(default='USR.PROFILE', max_length=200, null=True),
        ),
        migrations.AlterField(
            model_name='clientequery',
            name='origem_delete_tipo',
            field=models.CharField(default='USR.PROFILE', max_length=200, null=True),
        ),
        migrations.AlterField(
            model_name='clientequery',
            name='origem_edicao_tipo',
            field=models.CharField(default='USR.PROFILE', max_length=200, null=True),
        ),
        migrations.AlterField(
            model_name='clientequery',
            name='origem_insercao_tipo',
            field=models.CharField(default='USR.PROFILE', max_length=200, null=True),
        ),
        migrations.AlterField(
            model_name='fornecedorerro',
            name='origem_delete_tipo',
            field=models.CharField(default='USR.PROFILE', max_length=200, null=True),
        ),
        migrations.AlterField(
            model_name='fornecedorerro',
            name='origem_edicao_tipo',
            field=models.CharField(default='USR.PROFILE', max_length=200, null=True),
        ),
        migrations.AlterField(
            model_name='fornecedorerro',
            name='origem_insercao_tipo',
            field=models.CharField(default='USR.PROFILE', max_length=200, null=True),
        ),
        migrations.AlterField(
            model_name='fornecedorlog',
            name='origem_delete_tipo',
            field=models.CharField(default='USR.PROFILE', max_length=200, null=True),
        ),
        migrations.AlterField(
            model_name='fornecedorlog',
            name='origem_edicao_tipo',
            field=models.CharField(default='USR.PROFILE', max_length=200, null=True),
        ),
        migrations.AlterField(
            model_name='fornecedorlog',
            name='origem_insercao_tipo',
            field=models.CharField(default='USR.PROFILE', max_length=200, null=True),
        ),
        migrations.AlterField(
            model_name='fornecedorquery',
            name='origem_delete_tipo',
            field=models.CharField(default='USR.PROFILE', max_length=200, null=True),
        ),
        migrations.AlterField(
            model_name='fornecedorquery',
            name='origem_edicao_tipo',
            field=models.CharField(default='USR.PROFILE', max_length=200, null=True),
        ),
        migrations.AlterField(
            model_name='fornecedorquery',
            name='origem_insercao_tipo',
            field=models.CharField(default='USR.PROFILE', max_length=200, null=True),
        ),
        migrations.AlterField(
            model_name='indicadorerro',
            name='origem_delete_tipo',
            field=models.CharField(default='USR.PROFILE', max_length=200, null=True),
        ),
        migrations.AlterField(
            model_name='indicadorerro',
            name='origem_edicao_tipo',
            field=models.CharField(default='USR.PROFILE', max_length=200, null=True),
        ),
        migrations.AlterField(
            model_name='indicadorerro',
            name='origem_insercao_tipo',
            field=models.CharField(default='USR.PROFILE', max_length=200, null=True),
        ),
        migrations.AlterField(
            model_name='indicadorlog',
            name='origem_delete_tipo',
            field=models.CharField(default='USR.PROFILE', max_length=200, null=True),
        ),
        migrations.AlterField(
            model_name='indicadorlog',
            name='origem_edicao_tipo',
            field=models.CharField(default='USR.PROFILE', max_length=200, null=True),
        ),
        migrations.AlterField(
            model_name='indicadorlog',
            name='origem_insercao_tipo',
            field=models.CharField(default='USR.PROFILE', max_length=200, null=True),
        ),
        migrations.AlterField(
            model_name='indicadorquery',
            name='origem_delete_tipo',
            field=models.CharField(default='USR.PROFILE', max_length=200, null=True),
        ),
        migrations.AlterField(
            model_name='indicadorquery',
            name='origem_edicao_tipo',
            field=models.CharField(default='USR.PROFILE', max_length=200, null=True),
        ),
        migrations.AlterField(
            model_name='indicadorquery',
            name='origem_insercao_tipo',
            field=models.CharField(default='USR.PROFILE', max_length=200, null=True),
        ),
        migrations.AlterField(
            model_name='processoserro',
            name='origem_delete_tipo',
            field=models.CharField(default='USR.PROFILE', max_length=200, null=True),
        ),
        migrations.AlterField(
            model_name='processoserro',
            name='origem_edicao_tipo',
            field=models.CharField(default='USR.PROFILE', max_length=200, null=True),
        ),
        migrations.AlterField(
            model_name='processoserro',
            name='origem_insercao_tipo',
            field=models.CharField(default='USR.PROFILE', max_length=200, null=True),
        ),
        migrations.AlterField(
            model_name='processoslog',
            name='origem_delete_tipo',
            field=models.CharField(default='USR.PROFILE', max_length=200, null=True),
        ),
        migrations.AlterField(
            model_name='processoslog',
            name='origem_edicao_tipo',
            field=models.CharField(default='USR.PROFILE', max_length=200, null=True),
        ),
        migrations.AlterField(
            model_name='processoslog',
            name='origem_insercao_tipo',
            field=models.CharField(default='USR.PROFILE', max_length=200, null=True),
        ),
        migrations.AlterField(
            model_name='processosquery',
            name='origem_delete_tipo',
            field=models.CharField(default='USR.PROFILE', max_length=200, null=True),
        ),
        migrations.AlterField(
            model_name='processosquery',
            name='origem_edicao_tipo',
            field=models.CharField(default='USR.PROFILE', max_length=200, null=True),
        ),
        migrations.AlterField(
            model_name='processosquery',
            name='origem_insercao_tipo',
            field=models.CharField(default='USR.PROFILE', max_length=200, null=True),
        ),
        migrations.AlterField(
            model_name='venda_maiserro',
            name='origem_delete_tipo',
            field=models.CharField(default='USR.PROFILE', max_length=200, null=True),
        ),
        migrations.AlterField(
            model_name='venda_maiserro',
            name='origem_edicao_tipo',
            field=models.CharField(default='USR.PROFILE', max_length=200, null=True),
        ),
        migrations.AlterField(
            model_name='venda_maiserro',
            name='origem_insercao_tipo',
            field=models.CharField(default='USR.PROFILE', max_length=200, null=True),
        ),
        migrations.AlterField(
            model_name='venda_maislog',
            name='origem_delete_tipo',
            field=models.CharField(default='USR.PROFILE', max_length=200, null=True),
        ),
        migrations.AlterField(
            model_name='venda_maislog',
            name='origem_edicao_tipo',
            field=models.CharField(default='USR.PROFILE', max_length=200, null=True),
        ),
        migrations.AlterField(
            model_name='venda_maislog',
            name='origem_insercao_tipo',
            field=models.CharField(default='USR.PROFILE', max_length=200, null=True),
        ),
        migrations.AlterField(
            model_name='venda_maisquery',
            name='origem_delete_tipo',
            field=models.CharField(default='USR.PROFILE', max_length=200, null=True),
        ),
        migrations.AlterField(
            model_name='venda_maisquery',
            name='origem_edicao_tipo',
            field=models.CharField(default='USR.PROFILE', max_length=200, null=True),
        ),
        migrations.AlterField(
            model_name='venda_maisquery',
            name='origem_insercao_tipo',
            field=models.CharField(default='USR.PROFILE', max_length=200, null=True),
        ),
    ]
