# Generated by Django 2.1.7 on 2020-07-15 23:49

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('produto', '0008_auto_20200715_1931'),
    ]

    operations = [
        migrations.AlterField(
            model_name='produto',
            name='imagem',
            field=models.FileField(default='produtos/caixa-nissei.jpg', null=True, upload_to='produtos'),
        ),
        migrations.AlterField(
            model_name='produtoimagem',
            name='imagem',
            field=models.FileField(default='produtos/caixa-nissei.jpg', null=True, upload_to='produtos'),
        ),
    ]
