# Generated by Django 2.1.7 on 2020-08-05 19:32

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('funcionario', '0015_funcionario_imagem'),
    ]

    operations = [
        migrations.AlterField(
            model_name='funcionario',
            name='imagem',
            field=models.FileField(default='fotos/no-photo.png', null=True, upload_to='fotos/funcionarios'),
        ),
    ]
