# Generated by Django 2.1.7 on 2020-07-28 20:46

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('cliente', '0017_auto_20200728_1525'),
    ]

    operations = [
        migrations.AddField(
            model_name='endereco',
            name='bairro',
            field=models.CharField(max_length=100, null=True),
        ),
        migrations.AddField(
            model_name='endereco',
            name='rua',
            field=models.CharField(max_length=100, null=True),
        ),
    ]
