# Generated by Django 2.1.7 on 2020-08-05 19:52

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('core', '0013_auto_20200731_1612'),
    ]

    operations = [
        migrations.AddField(
            model_name='municipio',
            name='faixa_fim',
            field=models.CharField(max_length=80, null=True),
        ),
        migrations.AddField(
            model_name='municipio',
            name='faixa_ini',
            field=models.CharField(max_length=80, null=True),
        ),
        migrations.AddField(
            model_name='uf',
            name='faixa_fim',
            field=models.CharField(max_length=80, null=True),
        ),
        migrations.AddField(
            model_name='uf',
            name='faixa_ini',
            field=models.CharField(max_length=80, null=True),
        ),
    ]
