# Generated by Django 2.1.7 on 2020-07-28 16:10

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('cliente', '0011_auto_20200728_1233'),
    ]

    operations = [
        migrations.RenameField(
            model_name='cliente',
            old_name='celular',
            new_name='celular_completo_form',
        ),
        migrations.RenameField(
            model_name='cliente',
            old_name='telefone',
            new_name='telefone_completo_form',
        ),
        migrations.AddField(
            model_name='cliente',
            name='celular_completo',
            field=models.CharField(max_length=50, null=True),
        ),
        migrations.AddField(
            model_name='cliente',
            name='celular_numero',
            field=models.CharField(max_length=50, null=True),
        ),
        migrations.AddField(
            model_name='cliente',
            name='telefone_completo',
            field=models.CharField(max_length=50, null=True),
        ),
        migrations.AddField(
            model_name='cliente',
            name='telefone_nr',
            field=models.CharField(max_length=50, null=True),
        ),
    ]
