# Generated by Django 2.1.7 on 2020-08-05 19:53

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ('core', '0014_auto_20200805_1652'),
    ]

    operations = [
        migrations.RenameField(
            model_name='municipio',
            old_name='faixa_fim',
            new_name='cep_faixa_fim',
        ),
        migrations.RenameField(
            model_name='municipio',
            old_name='faixa_ini',
            new_name='cep_faixa_ini',
        ),
        migrations.RenameField(
            model_name='uf',
            old_name='faixa_fim',
            new_name='cep_faixa_fim',
        ),
        migrations.RenameField(
            model_name='uf',
            old_name='faixa_ini',
            new_name='cep_faixa_ini',
        ),
    ]
