# Generated by Django 2.1.7 on 2020-07-28 17:38

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('cliente', '0014_auto_20200728_1413'),
    ]

    operations = [
        migrations.AddField(
            model_name='termo',
            name='ordem',
            field=models.IntegerField(null=True),
        ),
    ]
