# Generated by Django 2.1.7 on 2020-08-06 21:30

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('usr', '0009_auto_20200805_1705'),
    ]

    operations = [
        migrations.AlterField(
            model_name='grupo',
            name='dat_delete',
            field=models.DateTimeField(blank=True, null=True),
        ),
        migrations.AlterField(
            model_name='grupouser',
            name='dat_delete',
            field=models.DateTimeField(blank=True, null=True),
        ),
    ]
