# Generated by Django 2.1.7 on 2020-07-16 16:51

import compositefk.fields
from django.db import migrations, models
import django.db.models.deletion


class Migration(migrations.Migration):

    dependencies = [
        ('core', '0005_auto_20200716_1347'),
        ('filial', '0006_auto_20200716_1348'),
    ]

    operations = [
        migrations.AddField(
            model_name='servico',
            name='tipo',
            field=compositefk.fields.CompositeForeignKey(null=True, null_if_equal=[], on_delete=django.db.models.deletion.DO_NOTHING, related_name='filial_servico_tipo', to='core.Tipo', to_fields={'codigo': compositefk.fields.LocalFieldValue('tipo_codigo'), 'tipo': compositefk.fields.LocalFieldValue('tipo_tipo')}),
        ),
        migrations.AddField(
            model_name='servico',
            name='tipo_codigo',
            field=models.CharField(max_length=200, null=True),
        ),
        migrations.AddField(
            model_name='servico',
            name='tipo_tipo',
            field=models.CharField(default='FILIAL.SERVICO', max_length=200, null=True),
        ),
    ]
