# Generated by Django 2.1.7 on 2020-08-05 19:50

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('produto', '0027_auto_20200805_1642'),
    ]

    operations = [
        migrations.RemoveField(
            model_name='estoquerede',
            name='origem_delete',
        ),
        migrations.RemoveField(
            model_name='estoquerede',
            name='origem_edicao',
        ),
        migrations.RemoveField(
            model_name='estoquerede',
            name='origem_insercao',
        ),
        migrations.RemoveField(
            model_name='estoquerede',
            name='produto',
        ),
        migrations.AddField(
            model_name='grupo',
            name='descricao',
            field=models.CharField(max_length=500, null=True),
        ),
        migrations.DeleteModel(
            name='EstoqueRede',
        ),
    ]
