# Generated by Django 2.1.7 on 2020-08-05 19:42

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('produto', '0026_marca_nome_emarca'),
    ]

    operations = [
        migrations.RemoveField(
            model_name='marca',
            name='nome_emarca',
        ),
        migrations.RemoveField(
            model_name='produto',
            name='marca_ecommerce',
        ),
        migrations.AddField(
            model_name='marca',
            name='nm_ecommerce',
            field=models.CharField(max_length=200, null=True),
        ),
    ]
