# Generated by Django 2.1.7 on 2020-08-05 19:32

from django.db import migrations, models
import django.db.models.deletion


class Migration(migrations.Migration):

    dependencies = [
        ('produto', '0024_auto_20200805_1632'),
    ]

    operations = [
        migrations.AddField(
            model_name='produto',
            name='tipo_produto',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.DO_NOTHING, to='produto.Tipo'),
        ),
    ]
