# Generated by Django 2.1.7 on 2020-07-22 21:48

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('produto', '0021_auto_20200722_0236'),
    ]

    operations = [
        migrations.RenameField(
            model_name='desconto',
            old_name='qtd_desc',
            new_name='qtd_fim_desc',
        ),
        migrations.AddField(
            model_name='desconto',
            name='qtd_ini_desc',
            field=models.IntegerField(null=True),
        ),
    ]
