# Generated by Django 2.1.7 on 2020-07-22 01:48

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('produto', '0019_auto_20200721_1412'),
    ]

    operations = [
        migrations.AddField(
            model_name='tipodesconto',
            name='tipo',
            field=models.CharField(max_length=10, null=True),
        ),
    ]
