# Generated by Django 2.1.7 on 2020-07-15 22:25

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ('core', '0002_auto_20200713_0030'),
    ]

    operations = [
        migrations.AlterModelOptions(
            name='cep',
            options={'managed': True},
        ),
        migrations.AlterModelOptions(
            name='data',
            options={'managed': True},
        ),
        migrations.AlterModelOptions(
            name='empresa',
            options={'managed': True},
        ),
        migrations.AlterModelOptions(
            name='erro',
            options={'managed': True},
        ),
        migrations.AlterModelOptions(
            name='hora',
            options={'managed': True},
        ),
        migrations.AlterModelOptions(
            name='municipio',
            options={'managed': True},
        ),
        migrations.AlterModelOptions(
            name='tipo',
            options={'managed': True},
        ),
        migrations.AlterModelOptions(
            name='uf',
            options={'managed': True},
        ),
    ]
