# Generated by Django 2.1.7 on 2020-08-05 19:29

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ('produto', '0022_auto_20200722_1848'),
    ]

    operations = [
        migrations.RemoveField(
            model_name='produto',
            name='tipo_produto',
        ),
    ]
