# Generated by Django 2.1.7 on 2020-08-05 19:40

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('produto', '0025_produto_tipo_produto'),
    ]

    operations = [
        migrations.AddField(
            model_name='marca',
            name='nome_emarca',
            field=models.CharField(max_length=60, null=True),
        ),
    ]
