# Create your views here.


# class Permissoes:
#     def sessao(self, request):
#         return 0
#
#
#     def pontos_funcao(self, request):
#         return 0
#
#
#     def view_login(self, request):
#         return 0
