# Generated by Django 2.1.7 on 2020-07-28 15:33

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('cliente', '0010_auto_20200720_1146'),
    ]

    operations = [
        migrations.AddField(
            model_name='cliente',
            name='celular_ddd',
            field=models.CharField(max_length=3, null=True),
        ),
        migrations.AddField(
            model_name='cliente',
            name='telefone_ddd',
            field=models.CharField(max_length=3, null=True),
        ),
    ]
