# Generated by Django 2.1.7 on 2020-08-05 20:05

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('filial', '0016_auto_20200731_1612'),
    ]

    operations = [
        migrations.AlterField(
            model_name='filial',
            name='origem_delete_codigo',
            field=models.CharField(blank=True, max_length=200, null=True),
        ),
        migrations.AlterField(
            model_name='filial',
            name='origem_delete_tipo',
            field=models.CharField(blank=True, default='USR.PROFILE', max_length=200, null=True),
        ),
        migrations.AlterField(
            model_name='filial',
            name='origem_edicao_codigo',
            field=models.CharField(blank=True, max_length=200, null=True),
        ),
        migrations.AlterField(
            model_name='filial',
            name='origem_edicao_tipo',
            field=models.CharField(blank=True, default='USR.PROFILE', max_length=200, null=True),
        ),
        migrations.AlterField(
            model_name='filial',
            name='origem_insercao_codigo',
            field=models.CharField(blank=True, max_length=200, null=True),
        ),
        migrations.AlterField(
            model_name='filial',
            name='origem_insercao_tipo',
            field=models.CharField(blank=True, default='USR.PROFILE', max_length=200, null=True),
        ),
        migrations.AlterField(
            model_name='filial',
            name='usr_delete',
            field=models.IntegerField(blank=True, null=True),
        ),
        migrations.AlterField(
            model_name='filial',
            name='usr_edicao',
            field=models.IntegerField(blank=True, null=True),
        ),
        migrations.AlterField(
            model_name='filial',
            name='usr_insercao',
            field=models.IntegerField(blank=True, null=True),
        ),
        migrations.AlterField(
            model_name='filialhorafuncionamento',
            name='origem_delete_codigo',
            field=models.CharField(blank=True, max_length=200, null=True),
        ),
        migrations.AlterField(
            model_name='filialhorafuncionamento',
            name='origem_delete_tipo',
            field=models.CharField(blank=True, default='USR.PROFILE', max_length=200, null=True),
        ),
        migrations.AlterField(
            model_name='filialhorafuncionamento',
            name='origem_edicao_codigo',
            field=models.CharField(blank=True, max_length=200, null=True),
        ),
        migrations.AlterField(
            model_name='filialhorafuncionamento',
            name='origem_edicao_tipo',
            field=models.CharField(blank=True, default='USR.PROFILE', max_length=200, null=True),
        ),
        migrations.AlterField(
            model_name='filialhorafuncionamento',
            name='origem_insercao_codigo',
            field=models.CharField(blank=True, max_length=200, null=True),
        ),
        migrations.AlterField(
            model_name='filialhorafuncionamento',
            name='origem_insercao_tipo',
            field=models.CharField(blank=True, default='USR.PROFILE', max_length=200, null=True),
        ),
        migrations.AlterField(
            model_name='filialhorafuncionamento',
            name='usr_delete',
            field=models.IntegerField(blank=True, null=True),
        ),
        migrations.AlterField(
            model_name='filialhorafuncionamento',
            name='usr_edicao',
            field=models.IntegerField(blank=True, null=True),
        ),
        migrations.AlterField(
            model_name='filialhorafuncionamento',
            name='usr_insercao',
            field=models.IntegerField(blank=True, null=True),
        ),
        migrations.AlterField(
            model_name='filialservico',
            name='origem_delete_codigo',
            field=models.CharField(blank=True, max_length=200, null=True),
        ),
        migrations.AlterField(
            model_name='filialservico',
            name='origem_delete_tipo',
            field=models.CharField(blank=True, default='USR.PROFILE', max_length=200, null=True),
        ),
        migrations.AlterField(
            model_name='filialservico',
            name='origem_edicao_codigo',
            field=models.CharField(blank=True, max_length=200, null=True),
        ),
        migrations.AlterField(
            model_name='filialservico',
            name='origem_edicao_tipo',
            field=models.CharField(blank=True, default='USR.PROFILE', max_length=200, null=True),
        ),
        migrations.AlterField(
            model_name='filialservico',
            name='origem_insercao_codigo',
            field=models.CharField(blank=True, max_length=200, null=True),
        ),
        migrations.AlterField(
            model_name='filialservico',
            name='origem_insercao_tipo',
            field=models.CharField(blank=True, default='USR.PROFILE', max_length=200, null=True),
        ),
        migrations.AlterField(
            model_name='filialservico',
            name='usr_delete',
            field=models.IntegerField(blank=True, null=True),
        ),
        migrations.AlterField(
            model_name='filialservico',
            name='usr_edicao',
            field=models.IntegerField(blank=True, null=True),
        ),
        migrations.AlterField(
            model_name='filialservico',
            name='usr_insercao',
            field=models.IntegerField(blank=True, null=True),
        ),
        migrations.AlterField(
            model_name='servico',
            name='origem_delete_codigo',
            field=models.CharField(blank=True, max_length=200, null=True),
        ),
        migrations.AlterField(
            model_name='servico',
            name='origem_delete_tipo',
            field=models.CharField(blank=True, default='USR.PROFILE', max_length=200, null=True),
        ),
        migrations.AlterField(
            model_name='servico',
            name='origem_edicao_codigo',
            field=models.CharField(blank=True, max_length=200, null=True),
        ),
        migrations.AlterField(
            model_name='servico',
            name='origem_edicao_tipo',
            field=models.CharField(blank=True, default='USR.PROFILE', max_length=200, null=True),
        ),
        migrations.AlterField(
            model_name='servico',
            name='origem_insercao_codigo',
            field=models.CharField(blank=True, max_length=200, null=True),
        ),
        migrations.AlterField(
            model_name='servico',
            name='origem_insercao_tipo',
            field=models.CharField(blank=True, default='USR.PROFILE', max_length=200, null=True),
        ),
        migrations.AlterField(
            model_name='servico',
            name='usr_delete',
            field=models.IntegerField(blank=True, null=True),
        ),
        migrations.AlterField(
            model_name='servico',
            name='usr_edicao',
            field=models.IntegerField(blank=True, null=True),
        ),
        migrations.AlterField(
            model_name='servico',
            name='usr_insercao',
            field=models.IntegerField(blank=True, null=True),
        ),
    ]
