# Generated by Django 2.1.7 on 2020-07-29 18:12

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ('log', '0009_clienteintegracao_fornecedorintegracao_indicadorintegracao_processosintegracao_venda_maisintegracao'),
    ]

    operations = [
        migrations.RenameField(
            model_name='clienteintegracao',
            old_name='data',
            new_name='body',
        ),
        migrations.RenameField(
            model_name='fornecedorintegracao',
            old_name='data',
            new_name='body',
        ),
        migrations.RenameField(
            model_name='indicadorintegracao',
            old_name='data',
            new_name='body',
        ),
        migrations.RenameField(
            model_name='processosintegracao',
            old_name='data',
            new_name='body',
        ),
        migrations.RenameField(
            model_name='venda_maisintegracao',
            old_name='data',
            new_name='body',
        ),
    ]
