# Generated by Django 2.1.7 on 2020-07-20 14:46

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('cliente', '0009_endereco_cep'),
    ]

    operations = [
        migrations.AlterField(
            model_name='avaliacao',
            name='origem_delete_tipo',
            field=models.CharField(default='USR.PROFILE', max_length=200, null=True),
        ),
        migrations.AlterField(
            model_name='avaliacao',
            name='origem_edicao_tipo',
            field=models.CharField(default='USR.PROFILE', max_length=200, null=True),
        ),
        migrations.AlterField(
            model_name='avaliacao',
            name='origem_insercao_tipo',
            field=models.CharField(default='USR.PROFILE', max_length=200, null=True),
        ),
        migrations.AlterField(
            model_name='cartao',
            name='origem_delete_tipo',
            field=models.CharField(default='USR.PROFILE', max_length=200, null=True),
        ),
        migrations.AlterField(
            model_name='cartao',
            name='origem_edicao_tipo',
            field=models.CharField(default='USR.PROFILE', max_length=200, null=True),
        ),
        migrations.AlterField(
            model_name='cartao',
            name='origem_insercao_tipo',
            field=models.CharField(default='USR.PROFILE', max_length=200, null=True),
        ),
        migrations.AlterField(
            model_name='cliente',
            name='origem_delete_tipo',
            field=models.CharField(default='USR.PROFILE', max_length=200, null=True),
        ),
        migrations.AlterField(
            model_name='cliente',
            name='origem_edicao_tipo',
            field=models.CharField(default='USR.PROFILE', max_length=200, null=True),
        ),
        migrations.AlterField(
            model_name='cliente',
            name='origem_insercao_tipo',
            field=models.CharField(default='USR.PROFILE', max_length=200, null=True),
        ),
        migrations.AlterField(
            model_name='clientetermo',
            name='origem_delete_tipo',
            field=models.CharField(default='USR.PROFILE', max_length=200, null=True),
        ),
        migrations.AlterField(
            model_name='clientetermo',
            name='origem_edicao_tipo',
            field=models.CharField(default='USR.PROFILE', max_length=200, null=True),
        ),
        migrations.AlterField(
            model_name='clientetermo',
            name='origem_insercao_tipo',
            field=models.CharField(default='USR.PROFILE', max_length=200, null=True),
        ),
        migrations.AlterField(
            model_name='cupom',
            name='origem_delete_tipo',
            field=models.CharField(default='USR.PROFILE', max_length=200, null=True),
        ),
        migrations.AlterField(
            model_name='cupom',
            name='origem_edicao_tipo',
            field=models.CharField(default='USR.PROFILE', max_length=200, null=True),
        ),
        migrations.AlterField(
            model_name='cupom',
            name='origem_insercao_tipo',
            field=models.CharField(default='USR.PROFILE', max_length=200, null=True),
        ),
        migrations.AlterField(
            model_name='endereco',
            name='origem_delete_tipo',
            field=models.CharField(default='USR.PROFILE', max_length=200, null=True),
        ),
        migrations.AlterField(
            model_name='endereco',
            name='origem_edicao_tipo',
            field=models.CharField(default='USR.PROFILE', max_length=200, null=True),
        ),
        migrations.AlterField(
            model_name='endereco',
            name='origem_insercao_tipo',
            field=models.CharField(default='USR.PROFILE', max_length=200, null=True),
        ),
        migrations.AlterField(
            model_name='favorito',
            name='origem_delete_tipo',
            field=models.CharField(default='USR.PROFILE', max_length=200, null=True),
        ),
        migrations.AlterField(
            model_name='favorito',
            name='origem_edicao_tipo',
            field=models.CharField(default='USR.PROFILE', max_length=200, null=True),
        ),
        migrations.AlterField(
            model_name='favorito',
            name='origem_insercao_tipo',
            field=models.CharField(default='USR.PROFILE', max_length=200, null=True),
        ),
        migrations.AlterField(
            model_name='receita',
            name='origem_delete_tipo',
            field=models.CharField(default='USR.PROFILE', max_length=200, null=True),
        ),
        migrations.AlterField(
            model_name='receita',
            name='origem_edicao_tipo',
            field=models.CharField(default='USR.PROFILE', max_length=200, null=True),
        ),
        migrations.AlterField(
            model_name='receita',
            name='origem_insercao_tipo',
            field=models.CharField(default='USR.PROFILE', max_length=200, null=True),
        ),
        migrations.AlterField(
            model_name='termo',
            name='origem_delete_tipo',
            field=models.CharField(default='USR.PROFILE', max_length=200, null=True),
        ),
        migrations.AlterField(
            model_name='termo',
            name='origem_edicao_tipo',
            field=models.CharField(default='USR.PROFILE', max_length=200, null=True),
        ),
        migrations.AlterField(
            model_name='termo',
            name='origem_insercao_tipo',
            field=models.CharField(default='USR.PROFILE', max_length=200, null=True),
        ),
    ]
