# Generated by Django 2.1.7 on 2020-07-16 15:05

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('produto', '0009_auto_20200715_2049'),
    ]

    operations = [
        migrations.AddField(
            model_name='categoria',
            name='nm_url_ecommerce',
            field=models.SlugField(max_length=100, null=True),
        ),
        migrations.AddField(
            model_name='especialidade',
            name='nm_url_ecommerce',
            field=models.SlugField(max_length=100, null=True),
        ),
        migrations.AddField(
            model_name='grupo',
            name='nm_url_ecommerce',
            field=models.SlugField(max_length=100, null=True),
        ),
        migrations.AddField(
            model_name='kit',
            name='nm_url_ecommerce',
            field=models.SlugField(max_length=100, null=True),
        ),
        migrations.AddField(
            model_name='marca',
            name='nm_url_ecommerce',
            field=models.SlugField(max_length=100, null=True),
        ),
        migrations.AddField(
            model_name='principioativo',
            name='nm_url_ecommerce',
            field=models.SlugField(max_length=100, null=True),
        ),
        migrations.AlterField(
            model_name='produto',
            name='nm_ecommerce',
            field=models.CharField(max_length=200, null=True),
        ),
        migrations.AlterField(
            model_name='produto',
            name='nm_url_ecommerce',
            field=models.SlugField(max_length=200, null=True),
        ),
    ]
