# Generated by Django 2.1.7 on 2020-08-03 20:05

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('cliente', '0022_auto_20200803_1608'),
    ]

    operations = [
        migrations.AddField(
            model_name='cartao',
            name='is_principal',
            field=models.BooleanField(default=False, null=True),
        ),
    ]
