# Generated by Django 2.1.7 on 2020-08-06 21:30

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('sistema', '0009_auto_20200805_1705'),
    ]

    operations = [
        migrations.AlterField(
            model_name='modulo',
            name='dat_delete',
            field=models.DateTimeField(blank=True, null=True),
        ),
        migrations.AlterField(
            model_name='perfil',
            name='dat_delete',
            field=models.DateTimeField(blank=True, null=True),
        ),
        migrations.AlterField(
            model_name='perfilgrupo',
            name='dat_delete',
            field=models.DateTimeField(blank=True, null=True),
        ),
        migrations.AlterField(
            model_name='perfillogin',
            name='dat_delete',
            field=models.DateTimeField(blank=True, null=True),
        ),
        migrations.AlterField(
            model_name='perfilpontofuncao',
            name='dat_delete',
            field=models.DateTimeField(blank=True, null=True),
        ),
        migrations.AlterField(
            model_name='pontofuncao',
            name='dat_delete',
            field=models.DateTimeField(blank=True, null=True),
        ),
        migrations.AlterField(
            model_name='versao',
            name='dat_delete',
            field=models.DateTimeField(blank=True, null=True),
        ),
        migrations.AlterField(
            model_name='versaoitem',
            name='dat_delete',
            field=models.DateTimeField(blank=True, null=True),
        ),
    ]
