# Generated by Django 2.1.7 on 2020-07-15 22:25

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ('cliente', '0002_auto_20200713_0030'),
    ]

    operations = [
        migrations.AlterModelOptions(
            name='avaliacao',
            options={'managed': True},
        ),
        migrations.AlterModelOptions(
            name='cartao',
            options={'managed': True},
        ),
        migrations.AlterModelOptions(
            name='cliente',
            options={'managed': True},
        ),
        migrations.AlterModelOptions(
            name='clientetermo',
            options={'managed': True},
        ),
        migrations.AlterModelOptions(
            name='cupom',
            options={'managed': True},
        ),
        migrations.AlterModelOptions(
            name='endereco',
            options={'managed': True},
        ),
        migrations.AlterModelOptions(
            name='favorito',
            options={'managed': True},
        ),
        migrations.AlterModelOptions(
            name='receita',
            options={'managed': True},
        ),
        migrations.AlterModelOptions(
            name='termo',
            options={'managed': True},
        ),
    ]
