# Generated by Django 2.1.7 on 2020-07-22 05:36

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ('produto', '0020_tipodesconto_tipo'),
    ]

    operations = [
        migrations.RenameField(
            model_name='produtoean',
            old_name='eab',
            new_name='ean',
        ),
    ]
