# Generated by Django 2.1.7 on 2020-08-03 19:08

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('cliente', '0021_auto_20200731_1612'),
    ]

    operations = [
        migrations.AddField(
            model_name='cartao',
            name='ano_val',
            field=models.IntegerField(null=True),
        ),
        migrations.AddField(
            model_name='cartao',
            name='cpf_titular_numero',
            field=models.CharField(max_length=200, null=True),
        ),
        migrations.AddField(
            model_name='cartao',
            name='mes_val',
            field=models.IntegerField(null=True),
        ),
        migrations.AddField(
            model_name='cartao',
            name='primeiros_6',
            field=models.CharField(max_length=6, null=True),
        ),
    ]
