# Generated by Django 2.1.7 on 2020-07-16 16:47

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ('produto', '0011_auto_20200716_1205'),
    ]

    operations = [
        migrations.AlterModelOptions(
            name='bula',
            options={'managed': True},
        ),
        migrations.AlterModelOptions(
            name='categoria',
            options={'managed': True},
        ),
        migrations.AlterModelOptions(
            name='desconto',
            options={'managed': True},
        ),
        migrations.AlterModelOptions(
            name='descontorelacao',
            options={'managed': True},
        ),
        migrations.AlterModelOptions(
            name='especialidade',
            options={'managed': True},
        ),
        migrations.AlterModelOptions(
            name='grupo',
            options={'managed': True},
        ),
        migrations.AlterModelOptions(
            name='kit',
            options={'managed': True},
        ),
        migrations.AlterModelOptions(
            name='marca',
            options={'managed': True},
        ),
        migrations.AlterModelOptions(
            name='precolista',
            options={'managed': True},
        ),
        migrations.AlterModelOptions(
            name='principioativo',
            options={'managed': True},
        ),
        migrations.AlterModelOptions(
            name='produto',
            options={'managed': True},
        ),
        migrations.AlterModelOptions(
            name='produtobula',
            options={'managed': True},
        ),
        migrations.AlterModelOptions(
            name='produtocategoria',
            options={'managed': True},
        ),
        migrations.AlterModelOptions(
            name='produtoean',
            options={'managed': True},
        ),
        migrations.AlterModelOptions(
            name='produtoespecialidade',
            options={'managed': True},
        ),
        migrations.AlterModelOptions(
            name='produtogrupo',
            options={'managed': True},
        ),
        migrations.AlterModelOptions(
            name='produtoimagem',
            options={'managed': True},
        ),
        migrations.AlterModelOptions(
            name='produtokit',
            options={'managed': True},
        ),
        migrations.AlterModelOptions(
            name='produtopreco',
            options={'managed': True},
        ),
        migrations.AlterModelOptions(
            name='produtoprincipioativo',
            options={'managed': True},
        ),
        migrations.AlterModelOptions(
            name='produtotiporeceita',
            options={'managed': True},
        ),
        migrations.AlterModelOptions(
            name='tipo',
            options={'managed': True},
        ),
        migrations.AlterModelOptions(
            name='tipodesconto',
            options={'managed': True},
        ),
        migrations.AlterModelOptions(
            name='tiporeceita',
            options={'managed': True},
        ),
    ]
