# Generated by Django 2.1.7 on 2020-07-17 13:34

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ('cliente', '0007_auto_20200716_1451'),
    ]

    operations = [
        migrations.RemoveField(
            model_name='endereco',
            name='cep',
        ),
    ]
