# Generated by Django 2.1.7 on 2020-07-28 20:16

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('core', '0009_auto_20200720_1146'),
    ]

    operations = [
        migrations.AddField(
            model_name='cep',
            name='cep_form',
            field=models.CharField(max_length=15, null=True),
        ),
    ]
