# Generated by Django 2.1.7 on 2020-08-05 19:29

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('cliente', '0024_cartao_cartao_id'),
    ]

    operations = [
        migrations.AddField(
            model_name='cliente',
            name='imagem',
            field=models.FileField(default='fotos/no-photo.png', null=True, upload_to='fotos/clientes'),
        ),
    ]
