# Generated by Django 2.1.7 on 2020-07-15 22:31

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ('produto', '0006_auto_20200715_1930'),
    ]

    operations = [
        migrations.RemoveField(
            model_name='preco',
            name='origem_delete',
        ),
        migrations.RemoveField(
            model_name='preco',
            name='origem_edicao',
        ),
        migrations.RemoveField(
            model_name='preco',
            name='origem_insercao',
        ),
        migrations.RemoveField(
            model_name='preco',
            name='produto',
        ),
        migrations.DeleteModel(
            name='Preco',
        ),
    ]
