# Generated by Django 2.1.7 on 2020-08-05 19:32

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('produto', '0023_remove_produto_tipo_produto'),
    ]

    operations = [
        migrations.RemoveField(
            model_name='tipo',
            name='id',
        ),
        migrations.AddField(
            model_name='tipo',
            name='nm_descritivo',
            field=models.CharField(max_length=200, null=True),
        ),
        migrations.AlterField(
            model_name='tipo',
            name='nome',
            field=models.CharField(default=1, max_length=100, primary_key=True, serialize=False),
            preserve_default=False,
        ),
    ]
