# Generated by Django 2.1.7 on 2020-07-16 15:05

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ('log', '0003_auto_20200715_1925'),
    ]

    operations = [
        migrations.AlterModelOptions(
            name='clienteerro',
            options={'managed': False},
        ),
        migrations.AlterModelOptions(
            name='clientelog',
            options={'managed': False},
        ),
        migrations.AlterModelOptions(
            name='clientequery',
            options={'managed': False},
        ),
        migrations.AlterModelOptions(
            name='fornecedorerro',
            options={'managed': False},
        ),
        migrations.AlterModelOptions(
            name='fornecedorlog',
            options={'managed': False},
        ),
        migrations.AlterModelOptions(
            name='fornecedorquery',
            options={'managed': False},
        ),
        migrations.AlterModelOptions(
            name='indicadorerro',
            options={'managed': False},
        ),
        migrations.AlterModelOptions(
            name='indicadorlog',
            options={'managed': False},
        ),
        migrations.AlterModelOptions(
            name='indicadorquery',
            options={'managed': False},
        ),
        migrations.AlterModelOptions(
            name='processoserro',
            options={'managed': False},
        ),
        migrations.AlterModelOptions(
            name='processoslog',
            options={'managed': False},
        ),
        migrations.AlterModelOptions(
            name='processosquery',
            options={'managed': False},
        ),
        migrations.AlterModelOptions(
            name='venda_maiserro',
            options={'managed': False},
        ),
        migrations.AlterModelOptions(
            name='venda_maislog',
            options={'managed': False},
        ),
        migrations.AlterModelOptions(
            name='venda_maisquery',
            options={'managed': False},
        ),
    ]
