# Generated by Django 2.1.7 on 2020-08-05 20:05

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('produto', '0028_auto_20200805_1650'),
    ]

    operations = [
        migrations.AlterField(
            model_name='bula',
            name='origem_delete_codigo',
            field=models.CharField(blank=True, max_length=200, null=True),
        ),
        migrations.AlterField(
            model_name='bula',
            name='origem_delete_tipo',
            field=models.CharField(blank=True, default='USR.PROFILE', max_length=200, null=True),
        ),
        migrations.AlterField(
            model_name='bula',
            name='origem_edicao_codigo',
            field=models.CharField(blank=True, max_length=200, null=True),
        ),
        migrations.AlterField(
            model_name='bula',
            name='origem_edicao_tipo',
            field=models.CharField(blank=True, default='USR.PROFILE', max_length=200, null=True),
        ),
        migrations.AlterField(
            model_name='bula',
            name='origem_insercao_codigo',
            field=models.CharField(blank=True, max_length=200, null=True),
        ),
        migrations.AlterField(
            model_name='bula',
            name='origem_insercao_tipo',
            field=models.CharField(blank=True, default='USR.PROFILE', max_length=200, null=True),
        ),
        migrations.AlterField(
            model_name='bula',
            name='usr_delete',
            field=models.IntegerField(blank=True, null=True),
        ),
        migrations.AlterField(
            model_name='bula',
            name='usr_edicao',
            field=models.IntegerField(blank=True, null=True),
        ),
        migrations.AlterField(
            model_name='bula',
            name='usr_insercao',
            field=models.IntegerField(blank=True, null=True),
        ),
        migrations.AlterField(
            model_name='categoria',
            name='origem_delete_codigo',
            field=models.CharField(blank=True, max_length=200, null=True),
        ),
        migrations.AlterField(
            model_name='categoria',
            name='origem_delete_tipo',
            field=models.CharField(blank=True, default='USR.PROFILE', max_length=200, null=True),
        ),
        migrations.AlterField(
            model_name='categoria',
            name='origem_edicao_codigo',
            field=models.CharField(blank=True, max_length=200, null=True),
        ),
        migrations.AlterField(
            model_name='categoria',
            name='origem_edicao_tipo',
            field=models.CharField(blank=True, default='USR.PROFILE', max_length=200, null=True),
        ),
        migrations.AlterField(
            model_name='categoria',
            name='origem_insercao_codigo',
            field=models.CharField(blank=True, max_length=200, null=True),
        ),
        migrations.AlterField(
            model_name='categoria',
            name='origem_insercao_tipo',
            field=models.CharField(blank=True, default='USR.PROFILE', max_length=200, null=True),
        ),
        migrations.AlterField(
            model_name='categoria',
            name='usr_delete',
            field=models.IntegerField(blank=True, null=True),
        ),
        migrations.AlterField(
            model_name='categoria',
            name='usr_edicao',
            field=models.IntegerField(blank=True, null=True),
        ),
        migrations.AlterField(
            model_name='categoria',
            name='usr_insercao',
            field=models.IntegerField(blank=True, null=True),
        ),
        migrations.AlterField(
            model_name='desconto',
            name='origem_delete_codigo',
            field=models.CharField(blank=True, max_length=200, null=True),
        ),
        migrations.AlterField(
            model_name='desconto',
            name='origem_delete_tipo',
            field=models.CharField(blank=True, default='USR.PROFILE', max_length=200, null=True),
        ),
        migrations.AlterField(
            model_name='desconto',
            name='origem_edicao_codigo',
            field=models.CharField(blank=True, max_length=200, null=True),
        ),
        migrations.AlterField(
            model_name='desconto',
            name='origem_edicao_tipo',
            field=models.CharField(blank=True, default='USR.PROFILE', max_length=200, null=True),
        ),
        migrations.AlterField(
            model_name='desconto',
            name='origem_insercao_codigo',
            field=models.CharField(blank=True, max_length=200, null=True),
        ),
        migrations.AlterField(
            model_name='desconto',
            name='origem_insercao_tipo',
            field=models.CharField(blank=True, default='USR.PROFILE', max_length=200, null=True),
        ),
        migrations.AlterField(
            model_name='desconto',
            name='usr_delete',
            field=models.IntegerField(blank=True, null=True),
        ),
        migrations.AlterField(
            model_name='desconto',
            name='usr_edicao',
            field=models.IntegerField(blank=True, null=True),
        ),
        migrations.AlterField(
            model_name='desconto',
            name='usr_insercao',
            field=models.IntegerField(blank=True, null=True),
        ),
        migrations.AlterField(
            model_name='descontoprodutopreco',
            name='origem_delete_codigo',
            field=models.CharField(blank=True, max_length=200, null=True),
        ),
        migrations.AlterField(
            model_name='descontoprodutopreco',
            name='origem_delete_tipo',
            field=models.CharField(blank=True, default='USR.PROFILE', max_length=200, null=True),
        ),
        migrations.AlterField(
            model_name='descontoprodutopreco',
            name='origem_edicao_codigo',
            field=models.CharField(blank=True, max_length=200, null=True),
        ),
        migrations.AlterField(
            model_name='descontoprodutopreco',
            name='origem_edicao_tipo',
            field=models.CharField(blank=True, default='USR.PROFILE', max_length=200, null=True),
        ),
        migrations.AlterField(
            model_name='descontoprodutopreco',
            name='origem_insercao_codigo',
            field=models.CharField(blank=True, max_length=200, null=True),
        ),
        migrations.AlterField(
            model_name='descontoprodutopreco',
            name='origem_insercao_tipo',
            field=models.CharField(blank=True, default='USR.PROFILE', max_length=200, null=True),
        ),
        migrations.AlterField(
            model_name='descontoprodutopreco',
            name='usr_delete',
            field=models.IntegerField(blank=True, null=True),
        ),
        migrations.AlterField(
            model_name='descontoprodutopreco',
            name='usr_edicao',
            field=models.IntegerField(blank=True, null=True),
        ),
        migrations.AlterField(
            model_name='descontoprodutopreco',
            name='usr_insercao',
            field=models.IntegerField(blank=True, null=True),
        ),
        migrations.AlterField(
            model_name='especialidade',
            name='origem_delete_codigo',
            field=models.CharField(blank=True, max_length=200, null=True),
        ),
        migrations.AlterField(
            model_name='especialidade',
            name='origem_delete_tipo',
            field=models.CharField(blank=True, default='USR.PROFILE', max_length=200, null=True),
        ),
        migrations.AlterField(
            model_name='especialidade',
            name='origem_edicao_codigo',
            field=models.CharField(blank=True, max_length=200, null=True),
        ),
        migrations.AlterField(
            model_name='especialidade',
            name='origem_edicao_tipo',
            field=models.CharField(blank=True, default='USR.PROFILE', max_length=200, null=True),
        ),
        migrations.AlterField(
            model_name='especialidade',
            name='origem_insercao_codigo',
            field=models.CharField(blank=True, max_length=200, null=True),
        ),
        migrations.AlterField(
            model_name='especialidade',
            name='origem_insercao_tipo',
            field=models.CharField(blank=True, default='USR.PROFILE', max_length=200, null=True),
        ),
        migrations.AlterField(
            model_name='especialidade',
            name='usr_delete',
            field=models.IntegerField(blank=True, null=True),
        ),
        migrations.AlterField(
            model_name='especialidade',
            name='usr_edicao',
            field=models.IntegerField(blank=True, null=True),
        ),
        migrations.AlterField(
            model_name='especialidade',
            name='usr_insercao',
            field=models.IntegerField(blank=True, null=True),
        ),
        migrations.AlterField(
            model_name='estoque',
            name='origem_delete_codigo',
            field=models.CharField(blank=True, max_length=200, null=True),
        ),
        migrations.AlterField(
            model_name='estoque',
            name='origem_delete_tipo',
            field=models.CharField(blank=True, default='USR.PROFILE', max_length=200, null=True),
        ),
        migrations.AlterField(
            model_name='estoque',
            name='origem_edicao_codigo',
            field=models.CharField(blank=True, max_length=200, null=True),
        ),
        migrations.AlterField(
            model_name='estoque',
            name='origem_edicao_tipo',
            field=models.CharField(blank=True, default='USR.PROFILE', max_length=200, null=True),
        ),
        migrations.AlterField(
            model_name='estoque',
            name='origem_insercao_codigo',
            field=models.CharField(blank=True, max_length=200, null=True),
        ),
        migrations.AlterField(
            model_name='estoque',
            name='origem_insercao_tipo',
            field=models.CharField(blank=True, default='USR.PROFILE', max_length=200, null=True),
        ),
        migrations.AlterField(
            model_name='estoque',
            name='usr_delete',
            field=models.IntegerField(blank=True, null=True),
        ),
        migrations.AlterField(
            model_name='estoque',
            name='usr_edicao',
            field=models.IntegerField(blank=True, null=True),
        ),
        migrations.AlterField(
            model_name='estoque',
            name='usr_insercao',
            field=models.IntegerField(blank=True, null=True),
        ),
        migrations.AlterField(
            model_name='grupo',
            name='origem_delete_codigo',
            field=models.CharField(blank=True, max_length=200, null=True),
        ),
        migrations.AlterField(
            model_name='grupo',
            name='origem_delete_tipo',
            field=models.CharField(blank=True, default='USR.PROFILE', max_length=200, null=True),
        ),
        migrations.AlterField(
            model_name='grupo',
            name='origem_edicao_codigo',
            field=models.CharField(blank=True, max_length=200, null=True),
        ),
        migrations.AlterField(
            model_name='grupo',
            name='origem_edicao_tipo',
            field=models.CharField(blank=True, default='USR.PROFILE', max_length=200, null=True),
        ),
        migrations.AlterField(
            model_name='grupo',
            name='origem_insercao_codigo',
            field=models.CharField(blank=True, max_length=200, null=True),
        ),
        migrations.AlterField(
            model_name='grupo',
            name='origem_insercao_tipo',
            field=models.CharField(blank=True, default='USR.PROFILE', max_length=200, null=True),
        ),
        migrations.AlterField(
            model_name='grupo',
            name='usr_delete',
            field=models.IntegerField(blank=True, null=True),
        ),
        migrations.AlterField(
            model_name='grupo',
            name='usr_edicao',
            field=models.IntegerField(blank=True, null=True),
        ),
        migrations.AlterField(
            model_name='grupo',
            name='usr_insercao',
            field=models.IntegerField(blank=True, null=True),
        ),
        migrations.AlterField(
            model_name='kit',
            name='origem_delete_codigo',
            field=models.CharField(blank=True, max_length=200, null=True),
        ),
        migrations.AlterField(
            model_name='kit',
            name='origem_delete_tipo',
            field=models.CharField(blank=True, default='USR.PROFILE', max_length=200, null=True),
        ),
        migrations.AlterField(
            model_name='kit',
            name='origem_edicao_codigo',
            field=models.CharField(blank=True, max_length=200, null=True),
        ),
        migrations.AlterField(
            model_name='kit',
            name='origem_edicao_tipo',
            field=models.CharField(blank=True, default='USR.PROFILE', max_length=200, null=True),
        ),
        migrations.AlterField(
            model_name='kit',
            name='origem_insercao_codigo',
            field=models.CharField(blank=True, max_length=200, null=True),
        ),
        migrations.AlterField(
            model_name='kit',
            name='origem_insercao_tipo',
            field=models.CharField(blank=True, default='USR.PROFILE', max_length=200, null=True),
        ),
        migrations.AlterField(
            model_name='kit',
            name='usr_delete',
            field=models.IntegerField(blank=True, null=True),
        ),
        migrations.AlterField(
            model_name='kit',
            name='usr_edicao',
            field=models.IntegerField(blank=True, null=True),
        ),
        migrations.AlterField(
            model_name='kit',
            name='usr_insercao',
            field=models.IntegerField(blank=True, null=True),
        ),
        migrations.AlterField(
            model_name='marca',
            name='origem_delete_codigo',
            field=models.CharField(blank=True, max_length=200, null=True),
        ),
        migrations.AlterField(
            model_name='marca',
            name='origem_delete_tipo',
            field=models.CharField(blank=True, default='USR.PROFILE', max_length=200, null=True),
        ),
        migrations.AlterField(
            model_name='marca',
            name='origem_edicao_codigo',
            field=models.CharField(blank=True, max_length=200, null=True),
        ),
        migrations.AlterField(
            model_name='marca',
            name='origem_edicao_tipo',
            field=models.CharField(blank=True, default='USR.PROFILE', max_length=200, null=True),
        ),
        migrations.AlterField(
            model_name='marca',
            name='origem_insercao_codigo',
            field=models.CharField(blank=True, max_length=200, null=True),
        ),
        migrations.AlterField(
            model_name='marca',
            name='origem_insercao_tipo',
            field=models.CharField(blank=True, default='USR.PROFILE', max_length=200, null=True),
        ),
        migrations.AlterField(
            model_name='marca',
            name='usr_delete',
            field=models.IntegerField(blank=True, null=True),
        ),
        migrations.AlterField(
            model_name='marca',
            name='usr_edicao',
            field=models.IntegerField(blank=True, null=True),
        ),
        migrations.AlterField(
            model_name='marca',
            name='usr_insercao',
            field=models.IntegerField(blank=True, null=True),
        ),
        migrations.AlterField(
            model_name='precolista',
            name='origem_delete_codigo',
            field=models.CharField(blank=True, max_length=200, null=True),
        ),
        migrations.AlterField(
            model_name='precolista',
            name='origem_delete_tipo',
            field=models.CharField(blank=True, default='USR.PROFILE', max_length=200, null=True),
        ),
        migrations.AlterField(
            model_name='precolista',
            name='origem_edicao_codigo',
            field=models.CharField(blank=True, max_length=200, null=True),
        ),
        migrations.AlterField(
            model_name='precolista',
            name='origem_edicao_tipo',
            field=models.CharField(blank=True, default='USR.PROFILE', max_length=200, null=True),
        ),
        migrations.AlterField(
            model_name='precolista',
            name='origem_insercao_codigo',
            field=models.CharField(blank=True, max_length=200, null=True),
        ),
        migrations.AlterField(
            model_name='precolista',
            name='origem_insercao_tipo',
            field=models.CharField(blank=True, default='USR.PROFILE', max_length=200, null=True),
        ),
        migrations.AlterField(
            model_name='precolista',
            name='usr_delete',
            field=models.IntegerField(blank=True, null=True),
        ),
        migrations.AlterField(
            model_name='precolista',
            name='usr_edicao',
            field=models.IntegerField(blank=True, null=True),
        ),
        migrations.AlterField(
            model_name='precolista',
            name='usr_insercao',
            field=models.IntegerField(blank=True, null=True),
        ),
        migrations.AlterField(
            model_name='principioativo',
            name='origem_delete_codigo',
            field=models.CharField(blank=True, max_length=200, null=True),
        ),
        migrations.AlterField(
            model_name='principioativo',
            name='origem_delete_tipo',
            field=models.CharField(blank=True, default='USR.PROFILE', max_length=200, null=True),
        ),
        migrations.AlterField(
            model_name='principioativo',
            name='origem_edicao_codigo',
            field=models.CharField(blank=True, max_length=200, null=True),
        ),
        migrations.AlterField(
            model_name='principioativo',
            name='origem_edicao_tipo',
            field=models.CharField(blank=True, default='USR.PROFILE', max_length=200, null=True),
        ),
        migrations.AlterField(
            model_name='principioativo',
            name='origem_insercao_codigo',
            field=models.CharField(blank=True, max_length=200, null=True),
        ),
        migrations.AlterField(
            model_name='principioativo',
            name='origem_insercao_tipo',
            field=models.CharField(blank=True, default='USR.PROFILE', max_length=200, null=True),
        ),
        migrations.AlterField(
            model_name='principioativo',
            name='usr_delete',
            field=models.IntegerField(blank=True, null=True),
        ),
        migrations.AlterField(
            model_name='principioativo',
            name='usr_edicao',
            field=models.IntegerField(blank=True, null=True),
        ),
        migrations.AlterField(
            model_name='principioativo',
            name='usr_insercao',
            field=models.IntegerField(blank=True, null=True),
        ),
        migrations.AlterField(
            model_name='produto',
            name='origem_delete_codigo',
            field=models.CharField(blank=True, max_length=200, null=True),
        ),
        migrations.AlterField(
            model_name='produto',
            name='origem_delete_tipo',
            field=models.CharField(blank=True, default='USR.PROFILE', max_length=200, null=True),
        ),
        migrations.AlterField(
            model_name='produto',
            name='origem_edicao_codigo',
            field=models.CharField(blank=True, max_length=200, null=True),
        ),
        migrations.AlterField(
            model_name='produto',
            name='origem_edicao_tipo',
            field=models.CharField(blank=True, default='USR.PROFILE', max_length=200, null=True),
        ),
        migrations.AlterField(
            model_name='produto',
            name='origem_insercao_codigo',
            field=models.CharField(blank=True, max_length=200, null=True),
        ),
        migrations.AlterField(
            model_name='produto',
            name='origem_insercao_tipo',
            field=models.CharField(blank=True, default='USR.PROFILE', max_length=200, null=True),
        ),
        migrations.AlterField(
            model_name='produto',
            name='usr_delete',
            field=models.IntegerField(blank=True, null=True),
        ),
        migrations.AlterField(
            model_name='produto',
            name='usr_edicao',
            field=models.IntegerField(blank=True, null=True),
        ),
        migrations.AlterField(
            model_name='produto',
            name='usr_insercao',
            field=models.IntegerField(blank=True, null=True),
        ),
        migrations.AlterField(
            model_name='produtobula',
            name='origem_delete_codigo',
            field=models.CharField(blank=True, max_length=200, null=True),
        ),
        migrations.AlterField(
            model_name='produtobula',
            name='origem_delete_tipo',
            field=models.CharField(blank=True, default='USR.PROFILE', max_length=200, null=True),
        ),
        migrations.AlterField(
            model_name='produtobula',
            name='origem_edicao_codigo',
            field=models.CharField(blank=True, max_length=200, null=True),
        ),
        migrations.AlterField(
            model_name='produtobula',
            name='origem_edicao_tipo',
            field=models.CharField(blank=True, default='USR.PROFILE', max_length=200, null=True),
        ),
        migrations.AlterField(
            model_name='produtobula',
            name='origem_insercao_codigo',
            field=models.CharField(blank=True, max_length=200, null=True),
        ),
        migrations.AlterField(
            model_name='produtobula',
            name='origem_insercao_tipo',
            field=models.CharField(blank=True, default='USR.PROFILE', max_length=200, null=True),
        ),
        migrations.AlterField(
            model_name='produtobula',
            name='usr_delete',
            field=models.IntegerField(blank=True, null=True),
        ),
        migrations.AlterField(
            model_name='produtobula',
            name='usr_edicao',
            field=models.IntegerField(blank=True, null=True),
        ),
        migrations.AlterField(
            model_name='produtobula',
            name='usr_insercao',
            field=models.IntegerField(blank=True, null=True),
        ),
        migrations.AlterField(
            model_name='produtocategoria',
            name='origem_delete_codigo',
            field=models.CharField(blank=True, max_length=200, null=True),
        ),
        migrations.AlterField(
            model_name='produtocategoria',
            name='origem_delete_tipo',
            field=models.CharField(blank=True, default='USR.PROFILE', max_length=200, null=True),
        ),
        migrations.AlterField(
            model_name='produtocategoria',
            name='origem_edicao_codigo',
            field=models.CharField(blank=True, max_length=200, null=True),
        ),
        migrations.AlterField(
            model_name='produtocategoria',
            name='origem_edicao_tipo',
            field=models.CharField(blank=True, default='USR.PROFILE', max_length=200, null=True),
        ),
        migrations.AlterField(
            model_name='produtocategoria',
            name='origem_insercao_codigo',
            field=models.CharField(blank=True, max_length=200, null=True),
        ),
        migrations.AlterField(
            model_name='produtocategoria',
            name='origem_insercao_tipo',
            field=models.CharField(blank=True, default='USR.PROFILE', max_length=200, null=True),
        ),
        migrations.AlterField(
            model_name='produtocategoria',
            name='usr_delete',
            field=models.IntegerField(blank=True, null=True),
        ),
        migrations.AlterField(
            model_name='produtocategoria',
            name='usr_edicao',
            field=models.IntegerField(blank=True, null=True),
        ),
        migrations.AlterField(
            model_name='produtocategoria',
            name='usr_insercao',
            field=models.IntegerField(blank=True, null=True),
        ),
        migrations.AlterField(
            model_name='produtoean',
            name='origem_delete_codigo',
            field=models.CharField(blank=True, max_length=200, null=True),
        ),
        migrations.AlterField(
            model_name='produtoean',
            name='origem_delete_tipo',
            field=models.CharField(blank=True, default='USR.PROFILE', max_length=200, null=True),
        ),
        migrations.AlterField(
            model_name='produtoean',
            name='origem_edicao_codigo',
            field=models.CharField(blank=True, max_length=200, null=True),
        ),
        migrations.AlterField(
            model_name='produtoean',
            name='origem_edicao_tipo',
            field=models.CharField(blank=True, default='USR.PROFILE', max_length=200, null=True),
        ),
        migrations.AlterField(
            model_name='produtoean',
            name='origem_insercao_codigo',
            field=models.CharField(blank=True, max_length=200, null=True),
        ),
        migrations.AlterField(
            model_name='produtoean',
            name='origem_insercao_tipo',
            field=models.CharField(blank=True, default='USR.PROFILE', max_length=200, null=True),
        ),
        migrations.AlterField(
            model_name='produtoean',
            name='usr_delete',
            field=models.IntegerField(blank=True, null=True),
        ),
        migrations.AlterField(
            model_name='produtoean',
            name='usr_edicao',
            field=models.IntegerField(blank=True, null=True),
        ),
        migrations.AlterField(
            model_name='produtoean',
            name='usr_insercao',
            field=models.IntegerField(blank=True, null=True),
        ),
        migrations.AlterField(
            model_name='produtoespecialidade',
            name='origem_delete_codigo',
            field=models.CharField(blank=True, max_length=200, null=True),
        ),
        migrations.AlterField(
            model_name='produtoespecialidade',
            name='origem_delete_tipo',
            field=models.CharField(blank=True, default='USR.PROFILE', max_length=200, null=True),
        ),
        migrations.AlterField(
            model_name='produtoespecialidade',
            name='origem_edicao_codigo',
            field=models.CharField(blank=True, max_length=200, null=True),
        ),
        migrations.AlterField(
            model_name='produtoespecialidade',
            name='origem_edicao_tipo',
            field=models.CharField(blank=True, default='USR.PROFILE', max_length=200, null=True),
        ),
        migrations.AlterField(
            model_name='produtoespecialidade',
            name='origem_insercao_codigo',
            field=models.CharField(blank=True, max_length=200, null=True),
        ),
        migrations.AlterField(
            model_name='produtoespecialidade',
            name='origem_insercao_tipo',
            field=models.CharField(blank=True, default='USR.PROFILE', max_length=200, null=True),
        ),
        migrations.AlterField(
            model_name='produtoespecialidade',
            name='usr_delete',
            field=models.IntegerField(blank=True, null=True),
        ),
        migrations.AlterField(
            model_name='produtoespecialidade',
            name='usr_edicao',
            field=models.IntegerField(blank=True, null=True),
        ),
        migrations.AlterField(
            model_name='produtoespecialidade',
            name='usr_insercao',
            field=models.IntegerField(blank=True, null=True),
        ),
        migrations.AlterField(
            model_name='produtogrupo',
            name='origem_delete_codigo',
            field=models.CharField(blank=True, max_length=200, null=True),
        ),
        migrations.AlterField(
            model_name='produtogrupo',
            name='origem_delete_tipo',
            field=models.CharField(blank=True, default='USR.PROFILE', max_length=200, null=True),
        ),
        migrations.AlterField(
            model_name='produtogrupo',
            name='origem_edicao_codigo',
            field=models.CharField(blank=True, max_length=200, null=True),
        ),
        migrations.AlterField(
            model_name='produtogrupo',
            name='origem_edicao_tipo',
            field=models.CharField(blank=True, default='USR.PROFILE', max_length=200, null=True),
        ),
        migrations.AlterField(
            model_name='produtogrupo',
            name='origem_insercao_codigo',
            field=models.CharField(blank=True, max_length=200, null=True),
        ),
        migrations.AlterField(
            model_name='produtogrupo',
            name='origem_insercao_tipo',
            field=models.CharField(blank=True, default='USR.PROFILE', max_length=200, null=True),
        ),
        migrations.AlterField(
            model_name='produtogrupo',
            name='usr_delete',
            field=models.IntegerField(blank=True, null=True),
        ),
        migrations.AlterField(
            model_name='produtogrupo',
            name='usr_edicao',
            field=models.IntegerField(blank=True, null=True),
        ),
        migrations.AlterField(
            model_name='produtogrupo',
            name='usr_insercao',
            field=models.IntegerField(blank=True, null=True),
        ),
        migrations.AlterField(
            model_name='produtoimagem',
            name='origem_delete_codigo',
            field=models.CharField(blank=True, max_length=200, null=True),
        ),
        migrations.AlterField(
            model_name='produtoimagem',
            name='origem_delete_tipo',
            field=models.CharField(blank=True, default='USR.PROFILE', max_length=200, null=True),
        ),
        migrations.AlterField(
            model_name='produtoimagem',
            name='origem_edicao_codigo',
            field=models.CharField(blank=True, max_length=200, null=True),
        ),
        migrations.AlterField(
            model_name='produtoimagem',
            name='origem_edicao_tipo',
            field=models.CharField(blank=True, default='USR.PROFILE', max_length=200, null=True),
        ),
        migrations.AlterField(
            model_name='produtoimagem',
            name='origem_insercao_codigo',
            field=models.CharField(blank=True, max_length=200, null=True),
        ),
        migrations.AlterField(
            model_name='produtoimagem',
            name='origem_insercao_tipo',
            field=models.CharField(blank=True, default='USR.PROFILE', max_length=200, null=True),
        ),
        migrations.AlterField(
            model_name='produtoimagem',
            name='usr_delete',
            field=models.IntegerField(blank=True, null=True),
        ),
        migrations.AlterField(
            model_name='produtoimagem',
            name='usr_edicao',
            field=models.IntegerField(blank=True, null=True),
        ),
        migrations.AlterField(
            model_name='produtoimagem',
            name='usr_insercao',
            field=models.IntegerField(blank=True, null=True),
        ),
        migrations.AlterField(
            model_name='produtokit',
            name='origem_delete_codigo',
            field=models.CharField(blank=True, max_length=200, null=True),
        ),
        migrations.AlterField(
            model_name='produtokit',
            name='origem_delete_tipo',
            field=models.CharField(blank=True, default='USR.PROFILE', max_length=200, null=True),
        ),
        migrations.AlterField(
            model_name='produtokit',
            name='origem_edicao_codigo',
            field=models.CharField(blank=True, max_length=200, null=True),
        ),
        migrations.AlterField(
            model_name='produtokit',
            name='origem_edicao_tipo',
            field=models.CharField(blank=True, default='USR.PROFILE', max_length=200, null=True),
        ),
        migrations.AlterField(
            model_name='produtokit',
            name='origem_insercao_codigo',
            field=models.CharField(blank=True, max_length=200, null=True),
        ),
        migrations.AlterField(
            model_name='produtokit',
            name='origem_insercao_tipo',
            field=models.CharField(blank=True, default='USR.PROFILE', max_length=200, null=True),
        ),
        migrations.AlterField(
            model_name='produtokit',
            name='usr_delete',
            field=models.IntegerField(blank=True, null=True),
        ),
        migrations.AlterField(
            model_name='produtokit',
            name='usr_edicao',
            field=models.IntegerField(blank=True, null=True),
        ),
        migrations.AlterField(
            model_name='produtokit',
            name='usr_insercao',
            field=models.IntegerField(blank=True, null=True),
        ),
        migrations.AlterField(
            model_name='produtopreco',
            name='origem_delete_codigo',
            field=models.CharField(blank=True, max_length=200, null=True),
        ),
        migrations.AlterField(
            model_name='produtopreco',
            name='origem_delete_tipo',
            field=models.CharField(blank=True, default='USR.PROFILE', max_length=200, null=True),
        ),
        migrations.AlterField(
            model_name='produtopreco',
            name='origem_edicao_codigo',
            field=models.CharField(blank=True, max_length=200, null=True),
        ),
        migrations.AlterField(
            model_name='produtopreco',
            name='origem_edicao_tipo',
            field=models.CharField(blank=True, default='USR.PROFILE', max_length=200, null=True),
        ),
        migrations.AlterField(
            model_name='produtopreco',
            name='origem_insercao_codigo',
            field=models.CharField(blank=True, max_length=200, null=True),
        ),
        migrations.AlterField(
            model_name='produtopreco',
            name='origem_insercao_tipo',
            field=models.CharField(blank=True, default='USR.PROFILE', max_length=200, null=True),
        ),
        migrations.AlterField(
            model_name='produtopreco',
            name='usr_delete',
            field=models.IntegerField(blank=True, null=True),
        ),
        migrations.AlterField(
            model_name='produtopreco',
            name='usr_edicao',
            field=models.IntegerField(blank=True, null=True),
        ),
        migrations.AlterField(
            model_name='produtopreco',
            name='usr_insercao',
            field=models.IntegerField(blank=True, null=True),
        ),
        migrations.AlterField(
            model_name='produtoprincipioativo',
            name='origem_delete_codigo',
            field=models.CharField(blank=True, max_length=200, null=True),
        ),
        migrations.AlterField(
            model_name='produtoprincipioativo',
            name='origem_delete_tipo',
            field=models.CharField(blank=True, default='USR.PROFILE', max_length=200, null=True),
        ),
        migrations.AlterField(
            model_name='produtoprincipioativo',
            name='origem_edicao_codigo',
            field=models.CharField(blank=True, max_length=200, null=True),
        ),
        migrations.AlterField(
            model_name='produtoprincipioativo',
            name='origem_edicao_tipo',
            field=models.CharField(blank=True, default='USR.PROFILE', max_length=200, null=True),
        ),
        migrations.AlterField(
            model_name='produtoprincipioativo',
            name='origem_insercao_codigo',
            field=models.CharField(blank=True, max_length=200, null=True),
        ),
        migrations.AlterField(
            model_name='produtoprincipioativo',
            name='origem_insercao_tipo',
            field=models.CharField(blank=True, default='USR.PROFILE', max_length=200, null=True),
        ),
        migrations.AlterField(
            model_name='produtoprincipioativo',
            name='usr_delete',
            field=models.IntegerField(blank=True, null=True),
        ),
        migrations.AlterField(
            model_name='produtoprincipioativo',
            name='usr_edicao',
            field=models.IntegerField(blank=True, null=True),
        ),
        migrations.AlterField(
            model_name='produtoprincipioativo',
            name='usr_insercao',
            field=models.IntegerField(blank=True, null=True),
        ),
        migrations.AlterField(
            model_name='produtotiporeceita',
            name='origem_delete_codigo',
            field=models.CharField(blank=True, max_length=200, null=True),
        ),
        migrations.AlterField(
            model_name='produtotiporeceita',
            name='origem_delete_tipo',
            field=models.CharField(blank=True, default='USR.PROFILE', max_length=200, null=True),
        ),
        migrations.AlterField(
            model_name='produtotiporeceita',
            name='origem_edicao_codigo',
            field=models.CharField(blank=True, max_length=200, null=True),
        ),
        migrations.AlterField(
            model_name='produtotiporeceita',
            name='origem_edicao_tipo',
            field=models.CharField(blank=True, default='USR.PROFILE', max_length=200, null=True),
        ),
        migrations.AlterField(
            model_name='produtotiporeceita',
            name='origem_insercao_codigo',
            field=models.CharField(blank=True, max_length=200, null=True),
        ),
        migrations.AlterField(
            model_name='produtotiporeceita',
            name='origem_insercao_tipo',
            field=models.CharField(blank=True, default='USR.PROFILE', max_length=200, null=True),
        ),
        migrations.AlterField(
            model_name='produtotiporeceita',
            name='usr_delete',
            field=models.IntegerField(blank=True, null=True),
        ),
        migrations.AlterField(
            model_name='produtotiporeceita',
            name='usr_edicao',
            field=models.IntegerField(blank=True, null=True),
        ),
        migrations.AlterField(
            model_name='produtotiporeceita',
            name='usr_insercao',
            field=models.IntegerField(blank=True, null=True),
        ),
        migrations.AlterField(
            model_name='tipo',
            name='origem_delete_codigo',
            field=models.CharField(blank=True, max_length=200, null=True),
        ),
        migrations.AlterField(
            model_name='tipo',
            name='origem_delete_tipo',
            field=models.CharField(blank=True, default='USR.PROFILE', max_length=200, null=True),
        ),
        migrations.AlterField(
            model_name='tipo',
            name='origem_edicao_codigo',
            field=models.CharField(blank=True, max_length=200, null=True),
        ),
        migrations.AlterField(
            model_name='tipo',
            name='origem_edicao_tipo',
            field=models.CharField(blank=True, default='USR.PROFILE', max_length=200, null=True),
        ),
        migrations.AlterField(
            model_name='tipo',
            name='origem_insercao_codigo',
            field=models.CharField(blank=True, max_length=200, null=True),
        ),
        migrations.AlterField(
            model_name='tipo',
            name='origem_insercao_tipo',
            field=models.CharField(blank=True, default='USR.PROFILE', max_length=200, null=True),
        ),
        migrations.AlterField(
            model_name='tipo',
            name='usr_delete',
            field=models.IntegerField(blank=True, null=True),
        ),
        migrations.AlterField(
            model_name='tipo',
            name='usr_edicao',
            field=models.IntegerField(blank=True, null=True),
        ),
        migrations.AlterField(
            model_name='tipo',
            name='usr_insercao',
            field=models.IntegerField(blank=True, null=True),
        ),
        migrations.AlterField(
            model_name='tipodesconto',
            name='origem_delete_codigo',
            field=models.CharField(blank=True, max_length=200, null=True),
        ),
        migrations.AlterField(
            model_name='tipodesconto',
            name='origem_delete_tipo',
            field=models.CharField(blank=True, default='USR.PROFILE', max_length=200, null=True),
        ),
        migrations.AlterField(
            model_name='tipodesconto',
            name='origem_edicao_codigo',
            field=models.CharField(blank=True, max_length=200, null=True),
        ),
        migrations.AlterField(
            model_name='tipodesconto',
            name='origem_edicao_tipo',
            field=models.CharField(blank=True, default='USR.PROFILE', max_length=200, null=True),
        ),
        migrations.AlterField(
            model_name='tipodesconto',
            name='origem_insercao_codigo',
            field=models.CharField(blank=True, max_length=200, null=True),
        ),
        migrations.AlterField(
            model_name='tipodesconto',
            name='origem_insercao_tipo',
            field=models.CharField(blank=True, default='USR.PROFILE', max_length=200, null=True),
        ),
        migrations.AlterField(
            model_name='tipodesconto',
            name='usr_delete',
            field=models.IntegerField(blank=True, null=True),
        ),
        migrations.AlterField(
            model_name='tipodesconto',
            name='usr_edicao',
            field=models.IntegerField(blank=True, null=True),
        ),
        migrations.AlterField(
            model_name='tipodesconto',
            name='usr_insercao',
            field=models.IntegerField(blank=True, null=True),
        ),
        migrations.AlterField(
            model_name='tiporeceita',
            name='origem_delete_codigo',
            field=models.CharField(blank=True, max_length=200, null=True),
        ),
        migrations.AlterField(
            model_name='tiporeceita',
            name='origem_delete_tipo',
            field=models.CharField(blank=True, default='USR.PROFILE', max_length=200, null=True),
        ),
        migrations.AlterField(
            model_name='tiporeceita',
            name='origem_edicao_codigo',
            field=models.CharField(blank=True, max_length=200, null=True),
        ),
        migrations.AlterField(
            model_name='tiporeceita',
            name='origem_edicao_tipo',
            field=models.CharField(blank=True, default='USR.PROFILE', max_length=200, null=True),
        ),
        migrations.AlterField(
            model_name='tiporeceita',
            name='origem_insercao_codigo',
            field=models.CharField(blank=True, max_length=200, null=True),
        ),
        migrations.AlterField(
            model_name='tiporeceita',
            name='origem_insercao_tipo',
            field=models.CharField(blank=True, default='USR.PROFILE', max_length=200, null=True),
        ),
        migrations.AlterField(
            model_name='tiporeceita',
            name='usr_delete',
            field=models.IntegerField(blank=True, null=True),
        ),
        migrations.AlterField(
            model_name='tiporeceita',
            name='usr_edicao',
            field=models.IntegerField(blank=True, null=True),
        ),
        migrations.AlterField(
            model_name='tiporeceita',
            name='usr_insercao',
            field=models.IntegerField(blank=True, null=True),
        ),
    ]
