# Generated by Django 2.1.7 on 2020-07-17 13:45

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ('filial', '0011_auto_20200717_1040'),
    ]

    operations = [
        migrations.RenameField(
            model_name='filial',
            old_name='codigo',
            new_name='cd_filial',
        ),
    ]
