# Generated by Django 2.1.7 on 2020-07-17 13:34

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('core', '0007_auto_20200716_1451'),
    ]

    operations = [
        migrations.RemoveField(
            model_name='cep',
            name='id',
        ),
        migrations.AlterField(
            model_name='cep',
            name='cep',
            field=models.CharField(default=1, max_length=10, primary_key=True, serialize=False),
            preserve_default=False,
        ),
    ]
